==> gimp-2.8.6.tar.xz: gimp-2.8.6/app/dialogs/dialogs-types.h <==
/* GIMP - The GNU Image Manipulation Program
 * Copyright (C) 1995 Spencer Kimball and Peter Mattis
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __DIALOGS_TYPES_H__
#define __DIALOGS_TYPES_H__


#include "display/display-types.h"


typedef void (* GimpScaleCallback) (GtkWidget             *dialog,
                                    GimpViewable          *viewable,
                                    gint                   width,
                                    gint                   height,
                                    GimpUnit               unit,
                                    GimpInterpolationType  interpolation,
                                    gdouble                xresolution,
                                    gdouble                yresolution,
                                    GimpUnit               resolution_unit,
                                    gpointer               user_data);


#endif /* __DIALOGS_TYPES_H__ */

==> gimp-3.0.6.tar.xz: gimp-3.0.6/app/dialogs/dialogs-types.h <==
/* GIMP - The GNU Image Manipulation Program
 * Copyright (C) 1995 Spencer Kimball and Peter Mattis
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

#ifndef __DIALOGS_TYPES_H__
#define __DIALOGS_TYPES_H__


#include "display/display-types.h"


typedef void (* GimpScaleCallback) (GtkWidget             *dialog,
                                    GimpViewable          *viewable,
                                    gint                   width,
                                    gint                   height,
                                    GimpUnit              *unit,
                                    GimpInterpolationType  interpolation,
                                    gdouble                xresolution,
                                    gdouble                yresolution,
                                    GimpUnit              *resolution_unit,
                                    gpointer               user_data);


#endif /* __DIALOGS_TYPES_H__ */
